@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2022-2023 Mike Fährmann
+# Copyright 2022-2025 Mike Fährmann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -26,9 +26,12 @@ from . import aes, text, util
 
 SUPPORTED_BROWSERS_CHROMIUM = {
     "brave", "chrome", "chromium", "edge", "opera", "thorium", "vivaldi"}
-SUPPORTED_BROWSERS_FIREFOX = {"firefox", "zen"}
+SUPPORTED_BROWSERS_FIREFOX = {"firefox", "librewolf", "zen"}
+SUPPORTED_BROWSERS_WEBKIT = {"safari", "orion"}
 SUPPORTED_BROWSERS = \
-    SUPPORTED_BROWSERS_CHROMIUM | SUPPORTED_BROWSERS_FIREFOX | {"safari"}
+    SUPPORTED_BROWSERS_CHROMIUM \
+    | SUPPORTED_BROWSERS_FIREFOX \
+    | SUPPORTED_BROWSERS_WEBKIT
 
 logger = logging.getLogger("cookies")
 
@@ -38,12 +41,12 @@ def load_cookies(browser_specification):
         _parse_browser_specification(*browser_specification)
     if browser_name in SUPPORTED_BROWSERS_FIREFOX:
         return load_cookies_firefox(browser_name, profile, container, domain)
-    elif browser_name == "safari":
-        return load_cookies_safari(profile, domain)
+    elif browser_name in SUPPORTED_BROWSERS_WEBKIT:
+        return load_cookies_webkit(browser_name, profile, domain)
     elif browser_name in SUPPORTED_BROWSERS_CHROMIUM:
         return load_cookies_chromium(browser_name, profile, keyring, domain)
     else:
-        raise ValueError("unknown browser '{}'".format(browser_name))
+        raise ValueError(f"unknown browser '{browser_name}'")
 
 
 def load_cookies_firefox(browser_name, profile=None,
@@ -59,7 +62,7 @@ def load_cookies_firefox(browser_name, profile=None,
     if container_id is False:
         conditions.append("NOT INSTR(originAttributes,'userContextId=')")
     elif container_id:
-        uid = "%userContextId={}".format(container_id)
+        uid = f"%userContextId={container_id}"
         conditions.append("originAttributes LIKE ? OR originAttributes LIKE ?")
         parameters += (uid, uid + "&%")
 
@@ -72,7 +75,7 @@ def load_cookies_firefox(browser_name, profile=None,
             parameters += (domain, "." + domain)
 
     if conditions:
-        sql = "{} WHERE ( {} )".format(sql, " ) AND ( ".join(conditions))
+        sql = f"{sql} WHERE ( {' ) AND ( '.join(conditions)} )"
 
     with DatabaseConnection(path) as db:
         cookies = [
@@ -92,7 +95,7 @@ def load_cookies_firefox(browser_name, profile=None,
     return cookies
 
 
-def load_cookies_safari(profile=None, domain=None):
+def load_cookies_webkit(browser_name, profile=None, domain=None):
     """Ref.: https://github.com/libyal/dtformats/blob
              /main/documentation/Safari%20Cookies.asciidoc
     - This data appears to be out of date
@@ -100,15 +103,24 @@ def load_cookies_safari(profile=None, domain=None):
     - There are a few bytes here and there
       which are skipped during parsing
     """
-    with _safari_cookies_database() as fp:
-        data = fp.read()
-    page_sizes, body_start = _safari_parse_cookies_header(data)
+    if browser_name == "safari":
+        with _safari_cookies_database() as fp:
+            data = fp.read()
+    elif browser_name == "orion":
+        with _orion_cookies_database() as fp:
+            data = fp.read()
+    else:
+        raise ValueError(f"unknown webkit browser '{browser_name}'")
+
+    page_sizes, body_start = _webkit_parse_cookies_header(data)
     p = DataParser(data[body_start:])
 
     cookies = []
     for page_size in page_sizes:
-        _safari_parse_cookies_page(p.read_bytes(page_size), cookies)
-    _log_info("Extracted %s cookies from Safari", len(cookies))
+        _webkit_parse_cookies_page(p.read_bytes(page_size), cookies)
+    _log_info("Extracted %s cookies from %s",
+              browser_name.capitalize(), len(cookies))
+
     return cookies
 
 
@@ -186,7 +198,7 @@ def load_cookies_chromium(browser_name, profile=None,
             ))
 
     if failed_cookies > 0:
-        failed_message = " ({} could not be decrypted)".format(failed_cookies)
+        failed_message = f" ({failed_cookies} could not be decrypted)"
     else:
         failed_message = ""
 
@@ -212,8 +224,9 @@ def _firefox_cookies_database(browser_name, profile=None, container=None):
 
     path = _find_most_recently_used_file(search_root, "cookies.sqlite")
     if path is None:
-        raise FileNotFoundError("Unable to find Firefox cookies database in "
-                                "{}".format(search_root))
+        raise FileNotFoundError(f"Unable to find {browser_name.capitalize()} "
+                                f"cookies database in {search_root}")
+
     _log_debug("Extracting cookies from %s", path)
 
     if not container or container == "none":
@@ -228,7 +241,7 @@ def _firefox_cookies_database(browser_name, profile=None, container=None):
             os.path.dirname(path), "containers.json")
 
         try:
-            with open(containers_path) as fp:
+            with open(containers_path, encoding="utf-8") as fp:
                 identities = util.json_loads(fp.read())["identities"]
         except OSError:
             _log_error("Unable to read Firefox container database at '%s'",
@@ -243,8 +256,7 @@ def _firefox_cookies_database(browser_name, profile=None, container=None):
                 container_id = context["userContextId"]
                 break
         else:
-            raise ValueError("Unable to find Firefox container '{}'".format(
-                container))
+            raise ValueError(f"Unable to find Firefox container '{container}'")
         _log_debug("Only loading cookies from container '%s' (ID %s)",
                    container, container_id)
 
@@ -257,25 +269,29 @@ def _firefox_browser_directory(browser_name):
     if sys.platform in ("win32", "cygwin"):
         appdata = os.path.expandvars("%APPDATA%")
         return {
-            "firefox": join(appdata, R"Mozilla\Firefox\Profiles"),
-            "zen"    : join(appdata, R"zen\Profiles")
+            "firefox"  : join(appdata, R"Mozilla\Firefox\Profiles"),
+            "librewolf": join(appdata, R"librewolf\Profiles"),
+            "zen"      : join(appdata, R"zen\Profiles"),
         }[browser_name]
     elif sys.platform == "darwin":
         appdata = os.path.expanduser("~/Library/Application Support")
         return {
-            "firefox": join(appdata, R"Firefox/Profiles"),
-            "zen"    : join(appdata, R"zen/Profiles")
+            "firefox"  : join(appdata, R"Firefox/Profiles"),
+            "librewolf": join(appdata, R"librewolf/Profiles"),
+            "zen"      : join(appdata, R"zen/Profiles"),
         }[browser_name]
     else:
         home = os.path.expanduser("~")
         return {
-            "firefox": join(home, R".mozilla/firefox"),
-            "zen"    : join(home, R".zen")
+            "firefox"  : join(home, R".mozilla/firefox"),
+            "librewolf": join(home, R".librewolf"),
+            "zen"      : join(home, R".zen"),
         }[browser_name]
 
 
 # --------------------------------------------------------------------
-# safari
+# safari/orion/webkit
+
 
 def _safari_cookies_database():
     try:
@@ -288,7 +304,13 @@ def _safari_cookies_database():
         return open(path, "rb")
 
 
-def _safari_parse_cookies_header(data):
+def _orion_cookies_database():
+    path = os.path.expanduser(
+        "~/Library/HTTPStorages/com.kagi.kagimacOS.binarycookies")
+    return open(path, "rb")
+
+
+def _webkit_parse_cookies_header(data):
     p = DataParser(data)
     p.expect_bytes(b"cook", "database signature")
     number_of_pages = p.read_uint(big_endian=True)
@@ -297,7 +319,7 @@ def _safari_parse_cookies_header(data):
     return page_sizes, p.cursor
 
 
-def _safari_parse_cookies_page(data, cookies, domain=None):
+def _webkit_parse_cookies_page(data, cookies, domain=None):
     p = DataParser(data)
     p.expect_bytes(b"\x00\x00\x01\x00", "page signature")
     number_of_cookies = p.read_uint()
@@ -310,13 +332,13 @@ def _safari_parse_cookies_page(data, cookies, domain=None):
 
     for i, record_offset in enumerate(record_offsets):
         p.skip_to(record_offset, "space between records")
-        record_length = _safari_parse_cookies_record(
+        record_length = _webkit_parse_cookies_record(
             data[record_offset:], cookies, domain)
         p.read_bytes(record_length)
     p.skip_to_end("space in between pages")
 
 
-def _safari_parse_cookies_record(data, cookies, host=None):
+def _webkit_parse_cookies_record(data, cookies, host=None):
     p = DataParser(data)
     record_size = p.read_uint()
     p.skip(4, "unknown record field 1")
@@ -352,7 +374,7 @@ def _safari_parse_cookies_record(data, cookies, host=None):
         p.skip_to(value_offset)
         value = p.read_cstring()
     except UnicodeDecodeError:
-        _log_warning("Failed to parse Safari cookie")
+        _log_warning("Failed to parse WebKit cookie")
         return record_size
 
     p.skip_to(record_size, "space at the end of the record")
@@ -386,8 +408,8 @@ def _chromium_cookies_database(profile, config):
 
     path = _find_most_recently_used_file(search_root, "Cookies")
     if path is None:
-        raise FileNotFoundError("Unable to find {} cookies database in "
-                                "'{}'".format(config["browser"], search_root))
+        raise FileNotFoundError(f"Unable to find {config['browser']} cookies "
+                                f"database in '{search_root}'")
     return path
 
 
@@ -519,8 +541,7 @@ class LinuxChromiumCookieDecryptor(ChromiumCookieDecryptor):
         self._cookie_counts = {"v10": 0, "v11": 0, "other": 0}
         self._offset = (32 if meta_version >= 24 else 0)
 
-    @staticmethod
-    def derive_key(password):
+    def derive_key(self, password):
         # values from
         # https://chromium.googlesource.com/chromium/src/+/refs/heads
         # /main/components/os_crypt/os_crypt_linux.cc
@@ -564,8 +585,7 @@ class MacChromiumCookieDecryptor(ChromiumCookieDecryptor):
         self._cookie_counts = {"v10": 0, "other": 0}
         self._offset = (32 if meta_version >= 24 else 0)
 
-    @staticmethod
-    def derive_key(password):
+    def derive_key(self, password):
         # values from
         # https://chromium.googlesource.com/chromium/src/+/refs/heads
         # /main/components/os_crypt/os_crypt_mac.mm
@@ -713,9 +733,9 @@ def _get_kwallet_password(browser_keyring_name):
         )
 
         if proc.returncode != 0:
-            _log_error("kwallet-query failed with return code {}. "
-                       "Please consult the kwallet-query man page "
-                       "for details".format(proc.returncode))
+            _log_error(f"kwallet-query failed with return code "
+                       f"{proc.returncode}. Please consult the kwallet-query "
+                       f"man page for details")
             return b""
 
         if stdout.lower().startswith(b"failed to read"):
@@ -844,7 +864,7 @@ class DataParser:
 
     def read_bytes(self, num_bytes):
         if num_bytes < 0:
-            raise ParserError("invalid read of {} bytes".format(num_bytes))
+            raise ParserError(f"invalid read of {num_bytes} bytes")
         end = self.cursor + num_bytes
         if end > len(self._data):
             raise ParserError("reached end of input")
@@ -855,8 +875,8 @@ class DataParser:
     def expect_bytes(self, expected_value, message):
         value = self.read_bytes(len(expected_value))
         if value != expected_value:
-            raise ParserError("unexpected value: {} != {} ({})".format(
-                value, expected_value, message))
+            raise ParserError(f"unexpected value: {value} != {expected_value} "
+                              f"({message})")
 
     def read_uint(self, big_endian=False):
         data_format = ">I" if big_endian else "<I"
@@ -877,10 +897,10 @@ class DataParser:
 
     def skip(self, num_bytes, description="unknown"):
         if num_bytes > 0:
-            _log_debug("Skipping {} bytes ({}): {!r}".format(
-                num_bytes, description, self.read_bytes(num_bytes)))
+            _log_debug(f"Skipping {num_bytes} bytes ({description}): "
+                       f"{self.read_bytes(num_bytes)!r}")
         elif num_bytes < 0:
-            raise ParserError("Invalid skip of {} bytes".format(num_bytes))
+            raise ParserError(f"Invalid skip of {num_bytes} bytes")
 
     def skip_to(self, offset, description="unknown"):
         self.skip(offset - self.cursor, description)
@@ -903,7 +923,7 @@ class DatabaseConnection():
             if util.WINDOWS:
                 path = "/" + os.path.abspath(path)
 
-            uri = "file:{}?mode=ro&immutable=1".format(path)
+            uri = f"file:{path}?mode=ro&immutable=1"
             self.database = sqlite3.connect(
                 uri, uri=True, isolation_level=None, check_same_thread=False)
             return self.database
@@ -1101,9 +1121,9 @@ def _parse_browser_specification(
         browser, profile=None, keyring=None, container=None, domain=None):
     browser = browser.lower()
     if browser not in SUPPORTED_BROWSERS:
-        raise ValueError("Unsupported browser '{}'".format(browser))
+        raise ValueError(f"Unsupported browser '{browser}'")
     if keyring and keyring not in SUPPORTED_KEYRINGS:
-        raise ValueError("Unsupported keyring '{}'".format(keyring))
+        raise ValueError(f"Unsupported keyring '{keyring}'")
     if profile and _is_path(profile):
         profile = os.path.expanduser(profile)
     return browser, profile, keyring, container, domain
