@@ -228,7 +228,8 @@ class Extractor():
                     break
 
             finally:
-                Extractor.request_timestamp = time.time()
+                if interval:
+                    Extractor.request_timestamp = time.time()
 
             self.log.debug("%s (%s/%s)", msg, tries, retries+1)
             if tries > retries:
@@ -262,6 +263,7 @@ class Extractor():
     def request_location(self, url, **kwargs):
         kwargs.setdefault("method", "HEAD")
         kwargs.setdefault("allow_redirects", False)
+        kwargs.setdefault("interval", False)
         return self.request(url, **kwargs).headers.get("location", "")
 
     def request_json(self, url, **kwargs):
@@ -354,12 +356,11 @@ class Extractor():
             raise exception.AbortExtraction(
                 f"User input required ({prompt.strip(' :')})")
 
-    def _get_auth_info(self):
+    def _get_auth_info(self, password=None):
         """Return authentication information as (username, password) tuple"""
         username = self.config("username")
-        password = None
 
-        if username:
+        if username or password:
             password = self.config("password")
             if not password:
                 self._check_input_allowed("password")
@@ -540,7 +541,7 @@ class Extractor():
         elif isinstance(cookies_source, str):
             path = util.expand_path(cookies_source)
             try:
-                with open(path) as fp:
+                with open(path, encoding="utf-8") as fp:
                     cookies = util.cookiestxt_load(fp)
             except ValueError as exc:
                 self.log.warning("cookies: Invalid Netscape cookies.txt file "
@@ -598,7 +599,7 @@ class Extractor():
 
         path_tmp = path + ".tmp"
         try:
-            with open(path_tmp, "w") as fp:
+            with open(path_tmp, "w", encoding="utf-8") as fp:
                 util.cookiestxt_store(fp, self.cookies)
             os.replace(path_tmp, path)
         except OSError as exc:
@@ -667,12 +668,18 @@ class Extractor():
         return False
 
     def _extract_jsonld(self, page):
-        return util.json_loads(text.extr(
-            page, '<script type="application/ld+json">', "</script>"))
+        return util.json_loads(
+            text.extr(page, '<script type="application/ld+json">',
+                      "</script>") or
+            text.extr(page, "<script type='application/ld+json'>",
+                      "</script>"))
 
     def _extract_nextdata(self, page):
-        return util.json_loads(text.extr(
-            page, ' id="__NEXT_DATA__" type="application/json">', "</script>"))
+        return util.json_loads(
+            text.extr(page, ' id="__NEXT_DATA__" type="application/json">',
+                      "</script>") or
+            text.extr(page, " id='__NEXT_DATA__' type='application/json'>",
+                      "</script>"))
 
     def _cache(self, func, maxage, keyarg=None):
         #  return cache.DatabaseCacheDecorator(func, maxage, keyarg)
