@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2019-2021 Mike Fährmann
+# Copyright 2019-2025 Mike Fährmann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -20,15 +20,12 @@ class NsfwalbumAlbumExtractor(GalleryExtractor):
     filename_fmt = "{album_id}_{num:>03}_{id}.{extension}"
     directory_fmt = ("{category}", "{album_id} {title}")
     archive_fmt = "{id}"
+    referer = False
     pattern = r"(?:https?://)?(?:www\.)?nsfwalbum\.com(/album/(\d+))"
-    test = ("https://nsfwalbum.com/album/401611", {
-        "range": "1-5",
-        "url": "b0481fc7fad5982da397b6359fbed8421b8ba284",
-        "keyword": "e98f9b0d473c00000831618d0235863b1dd78294",
-    })
+    example = "https://nsfwalbum.com/album/12345"
 
     def __init__(self, match):
-        self.album_id = match.group(2)
+        self.album_id = match[2]
         GalleryExtractor.__init__(self, match)
 
     def metadata(self, page):
@@ -56,7 +53,7 @@ class NsfwalbumAlbumExtractor(GalleryExtractor):
                             self.request(iframe + image_id).text,
                             'giraffe.annihilate("', '"')[0])
                         params = {"spirit": spirit, "photo": image_id}
-                    data = self.request(backend, params=params).json()
+                    data = self.request_json(backend, params=params)
                     break
                 except Exception:
                     tries += 1
@@ -69,16 +66,15 @@ class NsfwalbumAlbumExtractor(GalleryExtractor):
                 "width" : text.parse_int(data[1]),
                 "height": text.parse_int(data[2]),
                 "_http_validate": self._validate_response,
-                "_fallback": ("{}/imageProxy.php?photoId={}&spirit={}".format(
-                    self.root, image_id, spirit),),
+                "_fallback": (f"{self.root}/imageProxy.php"
+                              f"?photoId={image_id}&spirit={spirit}",),
             }
 
-    @staticmethod
-    def _validate_response(response):
-        return not response.request.url.endswith("/no_image.jpg")
+    def _validate_response(self, response):
+        return not response.url.endswith(
+            ("/no_image.jpg", "/placeholder.png", "/error.jpg"))
 
-    @staticmethod
-    def _annihilate(value, base=6):
+    def _annihilate(self, value, base=6):
         return "".join(
             chr(ord(char) ^ base)
             for char in value
