@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2016-2020 Mike Fährmann
+# Copyright 2016-2023 Mike Fährmann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -11,7 +11,6 @@
 from .common import Extractor, Message
 from .. import text, exception
 
-
 BASE_PATTERN = r"(?:https?://)?(?!www\.)([\w-]+)\.pixnet.net"
 
 
@@ -20,12 +19,11 @@ class PixnetExtractor(Extractor):
     category = "pixnet"
     filename_fmt = "{num:>03}_{id}.{extension}"
     archive_fmt = "{id}"
-    url_fmt = ""
 
     def __init__(self, match):
         Extractor.__init__(self, match)
-        self.blog, self.item_id = match.groups()
-        self.root = "https://{}.pixnet.net".format(self.blog)
+        self.blog, self.item_id = self.groups
+        self.root = f"https://{self.blog}.pixnet.net"
 
     def items(self):
         url = self.url_fmt.format(self.root, self.item_id)
@@ -54,8 +52,8 @@ class PixnetExtractor(Extractor):
 
             pnext = text.extr(page, 'class="nextBtn"', '>')
             if pnext is None and 'name="albumpass">' in page:
-                raise exception.StopExtraction(
-                    "Album %s is password-protected.", self.item_id)
+                raise exception.AbortExtraction(
+                    f"Album {self.item_id} is password-protected.")
             if "href" not in pnext:
                 return
             url = self.root + text.extr(pnext, 'href="', '"')
@@ -68,21 +66,17 @@ class PixnetImageExtractor(PixnetExtractor):
     filename_fmt = "{id}.{extension}"
     directory_fmt = ("{category}", "{blog}")
     pattern = BASE_PATTERN + r"/album/photo/(\d+)"
-    test = ("https://albertayu773.pixnet.net/album/photo/159443828", {
-        "url": "156564c422138914c9fa5b42191677b45c414af4",
-        "keyword": "19971bcd056dfef5593f4328a723a9602be0f087",
-        "content": "0e097bdf49e76dd9b9d57a016b08b16fa6a33280",
-    })
+    example = "https://USER.pixnet.net/album/photo/12345"
 
     def items(self):
         url = "https://api.pixnet.cc/oembed"
         params = {
-            "url": "https://{}.pixnet.net/album/photo/{}".format(
-                self.blog, self.item_id),
+            "url": (f"https://{self.blog}.pixnet.net"
+                    f"/album/photo/{self.item_id}"),
             "format": "json",
         }
 
-        data = self.request(url, params=params).json()
+        data = self.request_json(url, params=params)
         data["id"] = text.parse_int(
             data["url"].rpartition("/")[2].partition("-")[0])
         data["filename"], _, data["extension"] = data["title"].rpartition(".")
@@ -96,26 +90,13 @@ class PixnetImageExtractor(PixnetExtractor):
 class PixnetSetExtractor(PixnetExtractor):
     """Extractor for images from a pixnet set"""
     subcategory = "set"
-    url_fmt = "{}/album/set/{}"
     directory_fmt = ("{category}", "{blog}",
                      "{folder_id} {folder_title}", "{set_id} {set_title}")
     pattern = BASE_PATTERN + r"/album/set/(\d+)"
-    test = (
-        ("https://albertayu773.pixnet.net/album/set/15078995", {
-            "url": "6535712801af47af51110542f4938a7cef44557f",
-            "keyword": "bf25d59e5b0959cb1f53e7fd2e2a25f2f67e5925",
-        }),
-        ("https://anrine910070.pixnet.net/album/set/5917493", {
-            "url": "b3eb6431aea0bcf5003432a4a0f3a3232084fc13",
-            "keyword": "bf7004faa1cea18cf9bd856f0955a69be51b1ec6",
-        }),
-        ("https://sky92100.pixnet.net/album/set/17492544", {
-            "count": 0,  # password-protected
-        }),
-    )
+    example = "https://USER.pixnet.net/album/set/12345"
 
     def items(self):
-        url = self.url_fmt.format(self.root, self.item_id)
+        url = f"{self.root}/album/set/{self.item_id}"
         page = self.request(url, encoding="utf-8").text
         data = self.metadata(page)
 
@@ -157,10 +138,7 @@ class PixnetFolderExtractor(PixnetExtractor):
     subcategory = "folder"
     url_fmt = "{}/album/folder/{}"
     pattern = BASE_PATTERN + r"/album/folder/(\d+)"
-    test = ("https://albertayu773.pixnet.net/album/folder/1405768", {
-        "pattern": PixnetSetExtractor.pattern,
-        "count": ">= 15",
-    })
+    example = "https://USER.pixnet.net/album/folder/12345"
 
 
 class PixnetUserExtractor(PixnetExtractor):
@@ -168,16 +146,4 @@ class PixnetUserExtractor(PixnetExtractor):
     subcategory = "user"
     url_fmt = "{}{}/album/list"
     pattern = BASE_PATTERN + r"()(?:/blog|/album(?:/list)?)?/?(?:$|[?#])"
-    test = (
-        ("https://albertayu773.pixnet.net/"),
-        ("https://albertayu773.pixnet.net/blog"),
-        ("https://albertayu773.pixnet.net/album"),
-        ("https://albertayu773.pixnet.net/album/list", {
-            "pattern": PixnetFolderExtractor.pattern,
-            "count": ">= 30",
-        }),
-        ("https://anrine910070.pixnet.net/album/list", {
-            "pattern": PixnetSetExtractor.pattern,
-            "count": ">= 14",
-        }),
-    )
+    example = "https://USER.pixnet.net/"
