@@ -1026,11 +1026,12 @@ class TwitterTweetExtractor(TwitterExtractor):
             return
 
         while True:
+            parent_id = tweet["rest_id"]
             tweet_id = tweet["legacy"].get("quoted_status_id_str")
             if not tweet_id:
                 break
             tweet = self.api.tweet_result_by_rest_id(tweet_id)
-            tweet["legacy"]["quoted_by_id_str"] = tweet_id
+            tweet["legacy"]["quoted_by_id_str"] = parent_id
             yield tweet
 
     def _tweets_detail(self, tweet_id):
@@ -1447,20 +1448,33 @@ class TwitterAPI():
             "includePromotedContent": False,
         }
         return self._pagination_tweets(
-            endpoint, variables, ("bookmark_timeline_v2", "timeline"), False)
+            endpoint, variables, ("bookmark_timeline_v2", "timeline"),
+            stop_tweets=128)
 
     def search_timeline(self, query, product="Latest"):
         endpoint = "/graphql/4fpceYZ6-YQCx_JSl_Cn_A/SearchTimeline"
         variables = {
             "rawQuery": query,
-            "count": 100,
+            "count": self.extractor.config("search-limit", 20),
             "querySource": "typed_query",
             "product": product,
             "withGrokTranslatedBio": False,
         }
+
+        if self.extractor.config("search-pagination") in (
+                "max_id", "maxid", "id"):
+            update_variables = self._update_variables_search
+        else:
+            update_variables = None
+
+        stop_tweets = self.extractor.config("search-stop")
+        if stop_tweets is None or stop_tweets == "auto":
+            stop_tweets = 3 if update_variables is None else 0
+
         return self._pagination_tweets(
             endpoint, variables,
-            ("search_by_raw_query", "search_timeline", "timeline"))
+            ("search_by_raw_query", "search_timeline", "timeline"),
+            stop_tweets=stop_tweets, update_variables=update_variables)
 
     def community_query(self, community_id):
         endpoint = "/graphql/2W09l7nD7ZbxGQHXvfB22w/CommunityQuery"
@@ -1731,18 +1745,7 @@ class TwitterAPI():
                     retry = True
 
                 elif "Could not authenticate you" in msg:
-                    if not self.extractor.config("relogin", True):
-                        continue
-
-                    username, password = self.extractor._get_auth_info()
-                    if not username:
-                        continue
-
-                    _login_impl.invalidate(username)
-                    self.extractor.cookies_update(
-                        _login_impl(self.extractor, username, password))
-                    self.__init__(self.extractor)
-                    retry = True
+                    raise exception.AbortExtraction(f"'{msg}'")
 
                 elif msg.lower().startswith("timeout"):
                     retry = True
@@ -1870,11 +1873,12 @@ class TwitterAPI():
             params["cursor"] = extr._update_cursor(cursor)
 
     def _pagination_tweets(self, endpoint, variables,
-                           path=None, stop_tweets=True,
+                           path=None, stop_tweets=0, update_variables=None,
                            features=None, field_toggles=None):
         extr = self.extractor
         original_retweets = (extr.retweets == "original")
         pinned_tweet = extr.pinned
+        stop_tweets_max = stop_tweets
 
         params = {"variables": None}
         if cursor := extr._init_cursor():
@@ -2056,7 +2060,7 @@ class TwitterAPI():
                         quoted = tweet["quoted_status_result"]["result"]
                         quoted["legacy"]["quoted_by"] = (
                             tweet["core"]["user_results"]["result"]
-                            ["legacy"]["screen_name"])
+                            ["core"]["screen_name"])
                         quoted["legacy"]["quoted_by_id_str"] = tweet["rest_id"]
                         quoted["sortIndex"] = entry.get("sortIndex")
 
@@ -2067,11 +2071,24 @@ class TwitterAPI():
                             tweet.get("rest_id"))
                         continue
 
-            if stop_tweets and not tweet:
-                return extr._update_cursor(None)
+            if tweet:
+                stop_tweets = stop_tweets_max
+                last_tweet = tweet
+            else:
+                if stop_tweets <= 0:
+                    return extr._update_cursor(None)
+                self.log.debug(
+                    "No Tweet results (%s/%s)",
+                    stop_tweets_max - stop_tweets + 1, stop_tweets_max)
+                stop_tweets -= 1
+
             if not cursor or cursor == variables.get("cursor"):
                 return extr._update_cursor(None)
-            variables["cursor"] = extr._update_cursor(cursor)
+
+            if update_variables is None:
+                variables["cursor"] = extr._update_cursor(cursor)
+            else:
+                variables = update_variables(variables, cursor, last_tweet)
 
     def _pagination_users(self, endpoint, variables, path=None):
         extr = self.extractor
@@ -2140,182 +2157,33 @@ class TwitterAPI():
 
         self.log.debug("Skipping %s ('%s')", tweet_id, text)
 
+    def _update_variables_search(self, variables, cursor, tweet):
+        try:
+            tweet_id = tweet.get("id_str") or tweet["legacy"]["id_str"]
+            max_id = f"max_id:{int(tweet_id)-1}"
+
+            query, n = text.re(r"\bmax_id:\d+").subn(
+                max_id, variables["rawQuery"])
+            if n:
+                variables["rawQuery"] = query
+            else:
+                variables["rawQuery"] = f"{query} {max_id}"
+
+            if prefix := self.extractor._cursor_prefix:
+                self.extractor._cursor_prefix = \
+                    f"{prefix.partition('_')[0]}_{tweet_id}/"
+            variables["cursor"] = None
+        except Exception as exc:
+            self.extractor.log.debug(
+                "Failed to update 'max_id' search query (%s: %s). Falling "
+                "back to 'cursor' pagination", exc.__class__.__name__, exc)
+            variables["cursor"] = self.extractor._update_cursor(cursor)
+
+        return variables
+
 
 @cache(maxage=365*86400, keyarg=1)
 def _login_impl(extr, username, password):
-
-    def process(data, params=None):
-        response = extr.request(
-            url, params=params, headers=headers, json=data,
-            method="POST", fatal=None)
-
-        # update 'x-csrf-token' header (#5945)
-        if csrf_token := response.cookies.get("ct0"):
-            headers["x-csrf-token"] = csrf_token
-
-        try:
-            data = response.json()
-        except ValueError:
-            data = {"errors": ({"message": "Invalid response"},)}
-        else:
-            if response.status_code < 400:
-                try:
-                    return (data["flow_token"],
-                            data["subtasks"][0]["subtask_id"])
-                except LookupError:
-                    pass
-
-        errors = []
-        for error in data.get("errors") or ():
-            msg = error.get("message")
-            errors.append(f'"{msg}"' if msg else "Unknown error")
-        extr.log.debug(response.text)
-        raise exception.AuthenticationError(", ".join(errors))
-
-    cookies = extr.cookies
-    cookies.clear()
-    api = TwitterAPI(extr)
-    api._authenticate_guest()
-
-    url = "https://api.x.com/1.1/onboarding/task.json"
-    params = {"flow_name": "login"}
-    headers = api.headers
-
-    extr.log.info("Logging in as %s", username)
-
-    # init
-    data = {
-        "input_flow_data": {
-            "flow_context": {
-                "debug_overrides": {},
-                "start_location": {"location": "unknown"},
-            },
-        },
-        "subtask_versions": {
-            "action_list": 2,
-            "alert_dialog": 1,
-            "app_download_cta": 1,
-            "check_logged_in_account": 1,
-            "choice_selection": 3,
-            "contacts_live_sync_permission_prompt": 0,
-            "cta": 7,
-            "email_verification": 2,
-            "end_flow": 1,
-            "enter_date": 1,
-            "enter_email": 2,
-            "enter_password": 5,
-            "enter_phone": 2,
-            "enter_recaptcha": 1,
-            "enter_text": 5,
-            "enter_username": 2,
-            "generic_urt": 3,
-            "in_app_notification": 1,
-            "interest_picker": 3,
-            "js_instrumentation": 1,
-            "menu_dialog": 1,
-            "notifications_permission_prompt": 2,
-            "open_account": 2,
-            "open_home_timeline": 1,
-            "open_link": 1,
-            "phone_verification": 4,
-            "privacy_options": 1,
-            "security_key": 3,
-            "select_avatar": 4,
-            "select_banner": 2,
-            "settings_list": 7,
-            "show_code": 1,
-            "sign_up": 2,
-            "sign_up_review": 4,
-            "tweet_selection_urt": 1,
-            "update_users": 1,
-            "upload_media": 1,
-            "user_recommendations_list": 4,
-            "user_recommendations_urt": 1,
-            "wait_spinner": 3,
-            "web_modal": 1,
-        },
-    }
-
-    flow_token, subtask = process(data, params)
-    while not cookies.get("auth_token"):
-        if subtask == "LoginJsInstrumentationSubtask":
-            data = {
-                "js_instrumentation": {
-                    "response": "{}",
-                    "link": "next_link",
-                },
-            }
-        elif subtask == "LoginEnterUserIdentifierSSO":
-            data = {
-                "settings_list": {
-                    "setting_responses": [
-                        {
-                            "key": "user_identifier",
-                            "response_data": {
-                                "text_data": {"result": username},
-                            },
-                        },
-                    ],
-                    "link": "next_link",
-                },
-            }
-        elif subtask == "LoginEnterPassword":
-            data = {
-                "enter_password": {
-                    "password": password,
-                    "link": "next_link",
-                },
-            }
-        elif subtask == "LoginEnterAlternateIdentifierSubtask":
-            alt = extr.config("username-alt") or extr.input(
-                "Alternate Identifier (username, email, phone number): ")
-            data = {
-                "enter_text": {
-                    "text": alt,
-                    "link": "next_link",
-                },
-            }
-        elif subtask == "LoginTwoFactorAuthChallenge":
-            data = {
-                "enter_text": {
-                    "text": extr.input("2FA Token: "),
-                    "link": "next_link",
-                },
-            }
-        elif subtask == "LoginAcid":
-            data = {
-                "enter_text": {
-                    "text": extr.input("Email Verification Code: "),
-                    "link": "next_link",
-                },
-            }
-        elif subtask == "AccountDuplicationCheck":
-            data = {
-                "check_logged_in_account": {
-                    "link": "AccountDuplicationCheck_false",
-                },
-            }
-        elif subtask == "ArkoseLogin":
-            raise exception.AuthenticationError("Login requires CAPTCHA")
-        elif subtask == "DenyLoginSubtask":
-            raise exception.AuthenticationError("Login rejected as suspicious")
-        elif subtask == "LoginSuccessSubtask":
-            raise exception.AuthenticationError(
-                "No 'auth_token' cookie received")
-        else:
-            raise exception.AbortExtraction(f"Unrecognized subtask {subtask}")
-
-        inputs = {"subtask_id": subtask}
-        inputs.update(data)
-        data = {
-            "flow_token": flow_token,
-            "subtask_inputs": [inputs],
-        }
-
-        extr.sleep(random.uniform(1.0, 3.0), f"login ({subtask})")
-        flow_token, subtask = process(data)
-
-    return {
-        cookie.name: cookie.value
-        for cookie in extr.cookies
-    }
+    extr.log.error("Login with username & password is no longer supported. "
+                   "Use browser cookies instead.")
+    return {}
