@@ -17,8 +17,7 @@ class MtimePP(PostProcessor):
 
     def __init__(self, job, options):
         PostProcessor.__init__(self, job)
-        value = options.get("value")
-        if value:
+        if value := options.get("value"):
             self._get = formatter.parse(value, None, util.identity).format_map
         else:
             key = options.get("key", "date")
@@ -33,7 +32,10 @@ class MtimePP(PostProcessor):
 
     def run(self, pathfmt):
         mtime = self._get(pathfmt.kwdict)
-        pathfmt.kwdict["_mtime"] = (
+        if mtime is None:
+            return
+
+        pathfmt.kwdict["_mtime_meta"] = (
             util.datetime_to_timestamp(mtime)
             if isinstance(mtime, datetime) else
             text.parse_int(mtime)
