@@ -65,8 +65,8 @@ class ClientTransaction():
 
     @cache(maxage=36500*86400, keyarg=1)
     def _extract_indices(self, ondemand_s, extractor):
-        url = ("https://abs.twimg.com/responsive-web/client-web"
-               "/ondemand.s." + ondemand_s + "a.js")
+        url = (f"https://abs.twimg.com/responsive-web/client-web"
+               f"/ondemand.s.{ondemand_s}a.js")
         page = extractor.request(url).text
         pattern = util.re_compile(r"\(\w\[(\d\d?)\],\s*16\)")
         return [int(i) for i in pattern.findall(page)]
@@ -139,8 +139,7 @@ class ClientTransaction():
             (now >> 24) & 0xFF,
         )
 
-        payload = "{}!{}!{}{}{}".format(
-            method, path, now, keyword, self.animation_key)
+        payload = f"{method}!{path}!{now}{keyword}{self.animation_key}"
         bytes_hash = hashlib.sha256(payload.encode()).digest()[:16]
 
         num = (random.randrange(16) << 4) + int((nowf - nowi) * 16.0)
