@@ -229,7 +229,7 @@ class TestConfigFiles(unittest.TestCase):
             with open(path) as fp:
                 return util.json_loads(fp.read())
         except FileNotFoundError:
-            raise unittest.SkipTest(path + " not available")
+            raise unittest.SkipTest(f"{path} not available")
 
 
 if __name__ == "__main__":
